#!/bin/sh
#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006, 2009. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT
#------------------------------------------------------------------------------
# Description:   executes the db2cmd configCommonDB.sh scripts to create
# the CommonDB database
# Return Codes:  0 for success, non zero for failed
#
# Usage: 
#      configCommonDB.sh   [createDB]
# Parameters:
#      createDB    - specify whether or not  to create a new db 
#            
# Example:
#      configCommonDB.sh  createDB   //create a new db
#      configCommonDB.sh             // use an existing db
# Note: Make sure database setup correctly 
#	    On Unix system you must run  <user_home>/sqllib/db2profile before executing
#	    this script or manageprofiles  command or PMT tool. This is needed to 
#	    invoke db2 command for  creating a new database.
#	    Always run this script rather than running individual sql script else
#	    some tables might be created in wrong schema
#------------------------------------------------------------------------------
#-----------------------------------------
# Ask user for the database userid
#-----------------------------------------
get_userid() {
   while true; do
      if [ -n "$USER_NAME" ]; then
         USER_NAME=$USER_NAME
         break
      else
         echo         
		 echo "Enter DB2 user id ( user is required ): "
         read USER_NAME
         continue
      fi
   done
}

#-----------------------------------------
# Ask user for the database schema name
#-----------------------------------------
get_schema() {
  if [ -z "$DB_SCHEMA" ]; then
         echo 
         echo "The default value of the common database schema name is dbUserId. Enter schema name to cdbSchemaName value that you are using in the profile creation if it is different than default else hit Enter key:"
         read DB_SCHEMA
         DB_SCHEMA=$DB_SCHEMA
  fi

}


#-----------------------------------------
# Ask user for the database password
#-----------------------------------------
get_password() {
   while true; do
      if [ -n "$user_password" ]; then
          user_password=$user_password
          break
      else
          echo
	      trap 'stty echo;' 0 1 2 3 15
	      echo "Enter DB2 password( password is required ): "
	      stty -echo
	      read user_password
	      stty echo
          continue
      fi
   done
}

INIT_DIR=`pwd`
CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ] ; then
   CURRENT_DIR=`pwd`
fi

DB_CREATE=$1

################################
#  DB_NAME will be replaced 
################################
DB_NAME=@DB_NAME@

################################
#  DB_USER will be replaced 
################################
USER_NAME=@DB_USER@

################################
#  DB_SCHEMANAME will be replaced 
################################
DB_SCHEMA=@SCHEMA@


#call the following subroutine to get the db2 userid
get_userid
get_schema

if [ "$DB_SCHEMA" = "" ]; then
   DB_SCHEMA=$USER_NAME
fi
      

# call db2cmd env to execute command.
$CURRENT_DIR/createDBTables.sh  $USER_NAME $DB_NAME $DB_SCHEMA $DB_CREATE

cd $INIT_DIR
			