#!/bin/sh
#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006, 2009. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

#------------------------------------------------------------------------------
# Description:   Configure Oracle Database environment during Migrtaion based 
# 				 Migrating WBI version
#				 This file for use on Linux/Unix systems's bash
# 				 This script shall not be used if profileType is esbserver and product version is 602
#                Run the script always where it is located rather running from different folder
#
# Usage: 
#                upgradeSchema.sh   <profileType> <product_version>  <dbName> <dbCommonUserId>
#  
# Example:
#                upgradeSchema.sh wbiserver 620 orcl dbCommonUserId  
#                password will be prompted
#------------------------------------------------------------------------------

PROFILE_TYPE=$1
PRODUCT_VERSION=$2
DB_NAME=$3
DB_USER=$4

#-----------------------------------------
# Print Message
#-----------------------------------------
print_message() {
echo
echo =================================================================================================
echo "Usage: upgradeSchema.sh  <profileType>  <product_version>  <dbName> <dbCommonUserId>"
echo 
echo "Parameters:"
echo "profileType       -  Specify the migrated profileType  i.e., wbiserver or esbserver "
echo "product_version   -  Specify the migration version i.e., 620 or 602 or 610 or 612 "
echo "dbName            -  Oracle Instance Name(SID) i.e., orcl"
echo "dbCommonUserId    -  User who can execute common scripts i.e.,dbCommonUserId"
echo 
echo "Examples:"
echo "     1.upgradeSchema.sh -help "
echo "     1.upgradeSchema.sh [interactive mode] "
echo "     2.upgradeSchema.sh wbiserver 620 orcl dbCommonUserId"
echo "     Note: This script shall not be used if profileType is esbserver and product version is 602"
echo  
echo ====================================================================================================
echo
exit
}

#--------------------------------------------
# Not Supported Message
#--------------------------------------------
not_cdb_support() {
	if [ "$PROFILE_TYPE" == "esbserver"  -a "$PRODUCT_VERSION" == "602" ] ; then
		echo
  	  	echo Common Database Schema upgrade from esbserver 602 is not supported. 
		echo Check Migration Topics in InfoCenter for more information....
		exit
	fi
}

#-----------------------------------------
# Ask user for profileType of the product
#-----------------------------------------
get_profile_type() {
   while true; do
      if [ -n "$PROFILE_TYPE" ]; then
         PROFILE_TYPE=$PROFILE_TYPE
         break
      else
         echo
         echo "Enter profileType that you migrated [wbiserver | esbserver]:"
         read PROFILE_TYPE
         continue
      fi
   done
}

#-----------------------------------------
# Ask user for WBI migrtaion version
#-----------------------------------------
get_product_version() {
   while true; do
      if [ -n "$PRODUCT_VERSION" ]; then
         PRODUCT_VERSION=$PRODUCT_VERSION
         not_cdb_support
         break
      else
         echo         
		 echo "Enter product version that you migrated [620 | 612 | 610 | 602]:"
         read PRODUCT_VERSION
         continue
      fi
      not_cdb_support
   done
}

#--------------------------------------------
# Ask user for Database name
#--------------------------------------------
get_db_name() {
   while true; do
      if [ -n "$DB_NAME" ]; then
         DB_NAME=$DB_NAME
         break
      else
         echo         
		 echo "Enter Oracle SID[orcl]:"
         read DB_NAME
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for Database user
#--------------------------------------------
get_db_user() {
   while true; do
      if [ -n "$DB_USER" ]; then
         DB_USER=$DB_USER
         break
      else
         echo         
		 echo "Enter Oracle user[dbCommonUserId]:"
         read DB_USER
         continue
      fi
   done
}

if [ "$1" == "-h"  -o "$1" == "-help" ] ; then
   print_message
fi

if [ $# == 0 -o $# == 4  ]; then
	PROFILE_TYPE=$1
   	PRODUCT_VERSION=$2
	DB_NAME=$3
	DB_USER=$4
fi

INIT_DIR=`pwd`

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" = "." ] ; then
   CURRENT_DIR=`pwd`
fi

cd $CURRENT_DIR

#call the following subroutine to get oracle credentials
get_profile_type
not_cdb_support
get_product_version
get_db_name
get_db_user

#Connect to the database specifying the id and the password

ls | grep "^upgradeSchema${PRODUCT_VERSION}_" | sed s/^/\@/ > $PRODUCT_VERSION.sql

if [ "$PROFILE_TYPE" == "wbiserver" ] ; then
   ls | grep "^wbiserver_upgradeSchema${PRODUCT_VERSION}_" | sed s/^/\@/ >> $PRODUCT_VERSION.sql
fi

if [ "$PROFILE_TYPE" == "esbserver" ] ; then
   ls | grep "^esbserver_upgradeSchema${PRODUCT_VERSION}_" | sed s/^/\@/ >> $PRODUCT_VERSION.sql
fi

echo quit >> $PRODUCT_VERSION.sql

rc=0

sqlplus $DB_USER@$DB_NAME @$PRODUCT_VERSION.sql

rc=$?

rm -f  $PRODUCT_VERSION.sql

if [ $rc -ne 0 ] ; then
   	echo
    echo  "Check Oracle setup or Enter correct dbCommonUserId or dbCommonPassword or SID"
    echo 
    print_message
fi

cd $INIT_DIR

exit $?

